@@ -2,7 +2,7 @@
 # *****************************************************************************
 # ufit, a universal scattering fitting suite
 #
-# Copyright (c) 2013-2019, Georg Brandl and contributors.  All rights reserved.
+# Copyright (c) 2013-2021, Georg Brandl and contributors.  All rights reserved.
 # Licensed under a 2-clause BSD license, see LICENSE.
 # *****************************************************************************
 
@@ -54,7 +54,7 @@ def sanitize_meta(meta, name):
         meta.datafilename = ''
 
 
-class DataBase(object):
+class DataBase:
 
     def __init__(self, meta, name='', sources=None):
         self.meta = attrdict(meta)
