@@ -2,7 +2,7 @@
 # *****************************************************************************
 # ufit, a universal scattering fitting suite
 #
-# Copyright (c) 2013-2019, Georg Brandl and contributors.  All rights reserved.
+# Copyright (c) 2013-2021, Georg Brandl and contributors.  All rights reserved.
 # Licensed under a 2-clause BSD license, see LICENSE.
 # *****************************************************************************
 
@@ -85,6 +85,6 @@ def read_data(filename, fp):
             break
     if 'MAG' in cols:
         if meta['MAG'] > 0:
-            meta['environment'].append('B = %.3f K' % meta['B'])
+            meta['environment'].append('B = %.3f T' % meta['B'])
 
     return colnames, arr, meta
