@@ -2,7 +2,7 @@
 # *****************************************************************************
 # ufit, a universal scattering fitting suite
 #
-# Copyright (c) 2013-2019, Georg Brandl and contributors.  All rights reserved.
+# Copyright (c) 2013-2021, Georg Brandl and contributors.  All rights reserved.
 # Licensed under a 2-clause BSD license, see LICENSE.
 # *****************************************************************************
 
@@ -10,11 +10,11 @@
 
 from ufit.qt import pyqtSignal, QMainWindow
 
-from qtconsole.rich_ipython_widget import RichIPythonWidget
+from qtconsole.rich_jupyter_widget import RichJupyterWidget
 from qtconsole.inprocess import QtInProcessKernelManager
 
 
-class QIPythonWidget(RichIPythonWidget):
+class QIPythonWidget(RichJupyterWidget):
     """Convenience class for a live IPython console widget."""
 
     closeme = pyqtSignal()
@@ -23,10 +23,11 @@ class QIPythonWidget(RichIPythonWidget):
     def __init__(self, customBanner=None, *args, **kwargs):
         if customBanner is not None:
             self.banner = customBanner
+            self.kernel_banner = ''
         super(QIPythonWidget, self).__init__(*args, **kwargs)
         self.kernel_manager = kernel_manager = QtInProcessKernelManager()
         kernel_manager.start_kernel()
-        kernel_manager.kernel.gui = 'qt4'
+        kernel_manager.kernel.gui = 'qt'
         self.kernel_client = kernel_client = self._kernel_manager.client()
         kernel_client.start_channels()
 
