@@ -2,13 +2,13 @@
 # *****************************************************************************
 # ufit, a universal scattering fitting suite
 #
-# Copyright (c) 2013-2019, Georg Brandl and contributors.  All rights reserved.
+# Copyright (c) 2013-2022, Georg Brandl and contributors.  All rights reserved.
 # Licensed under a 2-clause BSD license, see LICENSE.
 # *****************************************************************************
 
 """Data operations panel."""
 
-from numpy import sqrt, ones, arange, linspace
+from numpy import ones, arange, linspace
 from scipy.interpolate import interp1d
 from scipy.fftpack import fft
 
@@ -18,6 +18,7 @@ from ufit.data.merge import rebin, floatmerge
 from ufit.data.dataset import ScanData
 from ufit.gui.common import loadUi, SettingGroup
 from ufit.gui.session import session
+from ufit.gui.mappingitem import MappingItem
 
 
 class DataOps(QWidget):
@@ -141,6 +142,11 @@ class DataOps(QWidget):
         from ufit.gui.scanitem import ScanDataItem
         session.add_item(ScanDataItem(new_data, new_model), self.item.group)
 
+    @pyqtSlot()
+    def on_mappingBtn_clicked(self):
+        item = MappingItem([self.data], None)
+        session.add_item(item, self.item.group)
+
     @pyqtSlot()
     def on_arbBtn_clicked(self):
         dlg = QDialog(self)
