@@ -2,7 +2,7 @@
 # *****************************************************************************
 # ufit, a universal scattering fitting suite
 #
-# Copyright (c) 2013-2019, Georg Brandl and contributors.  All rights reserved.
+# Copyright (c) 2013-2022, Georg Brandl and contributors.  All rights reserved.
 # Licensed under a 2-clause BSD license, see LICENSE.
 # *****************************************************************************
 
@@ -13,7 +13,6 @@ from ufit.qt import pyqtSignal, QByteArray, Qt, QMainWindow, QMessageBox, \
 
 from ufit.gui.common import loadUi, SettingGroup
 from ufit.gui.session import session
-from ufit.pycompat import srepr
 
 
 class InspectorWindow(QMainWindow):
@@ -51,7 +50,7 @@ class InspectorWindow(QMainWindow):
                 value_item = QTableWidgetItem(str(data.meta[key]))
                 value_item.setFlags(value_item.flags() & ~Qt.ItemIsEditable)
             else:
-                value_item = QTableWidgetItem(srepr(data.meta[key]))
+                value_item = QTableWidgetItem(repr(data.meta[key]))
             self.tbl.setItem(i, 1, value_item)
         self._updating = False
 
