@@ -2,7 +2,7 @@
 # *****************************************************************************
 # ufit, a universal scattering fitting suite
 #
-# Copyright (c) 2013-2019, Georg Brandl and contributors.  All rights reserved.
+# Copyright (c) 2013-2022, Georg Brandl and contributors.  All rights reserved.
 # Licensed under a 2-clause BSD license, see LICENSE.
 # *****************************************************************************
 
@@ -16,7 +16,7 @@ from ufit.qt import pyqtSignal, Qt, QSize, QAbstractItemModel, QModelIndex, \
 
 from ufit.gui.session import session, ItemGroup
 from ufit.gui.scanitem import ScanDataItem
-from ufit.pycompat import from_encoding
+from ufit.utils import from_encoding
 
 
 class ItemListWidget(QListWidget):
@@ -169,4 +169,5 @@ class ItemListDelegate(QStyledItemDelegate):
         document = QTextDocument()
         document.setDefaultFont(option.font)
         document.setHtml(text)
-        return QSize(document.idealWidth(), int(document.size().height()))
+        return QSize(round(document.idealWidth()),
+                     round(document.size().height()))
