@@ -2,7 +2,7 @@
 # *****************************************************************************
 # ufit, a universal scattering fitting suite
 #
-# Copyright (c) 2013-2019, Georg Brandl and contributors.  All rights reserved.
+# Copyright (c) 2013-2021, Georg Brandl and contributors.  All rights reserved.
 # Licensed under a 2-clause BSD license, see LICENSE.
 # *****************************************************************************
 
@@ -159,8 +159,10 @@ class LogfileHandler(StreamHandler):
             # if the symlink does not (yet) exist, OSError is raised.
             # should happen at most once per installation....
             pass
-        if hasattr(os, 'symlink'):
+        try:
             os.symlink(path.basename(self.baseFilename), self._currentsymlink)
+        except (AttributeError, OSError):
+            pass
         # finally open the new logfile....
         return open(self.baseFilename, 'a')
 
