@@ -2,7 +2,7 @@
 # *****************************************************************************
 # ufit, a universal scattering fitting suite
 #
-# Copyright (c) 2013-2020, Georg Brandl and contributors.  All rights reserved.
+# Copyright (c) 2013-2022, Georg Brandl and contributors.  All rights reserved.
 # Licensed under a 2-clause BSD license, see LICENSE.
 # *****************************************************************************
 
@@ -28,7 +28,6 @@ from ufit.gui.scanitem import ScanDataPanel, ScanDataItem
 from ufit.gui.imageitem import ImageDataItem
 from ufit.gui.session import session, temp_session, SessionItem, ItemGroup
 from ufit.gui.coverage import ReciprocalViewer
-from ufit.pycompat import listitems
 
 max_recent_files = 6
 
@@ -167,7 +166,7 @@ class UFitMain(QMainWindow):
 
     def on_session_itemsUpdated(self):
         # remove all panels whose item has vanished
-        for item, panel in listitems(self.itempanels):
+        for item, panel in list(self.itempanels.items()):
             if item not in session.all_items:
                 self.stacker.removeWidget(panel)
                 del self.itempanels[item]
@@ -511,7 +510,7 @@ class UFitMain(QMainWindow):
                          'activate the console part of this window.', new_win)
             splitter.addWidget(lbl)
         else:
-            iw = QIPythonWidget('interactive pylab plotting prompt', new_win)
+            iw = QIPythonWidget('interactive pylab plotting prompt\n', new_win)
             iw.pushVariables({'ax': canvas.axes})
             iw.executeCommand('from ufit.lab import *')
             iw.executeCommand('sca(ax)')
