@@ -2,19 +2,19 @@
 # *****************************************************************************
 # ufit, a universal scattering fitting suite
 #
-# Copyright (c) 2013-2019, Georg Brandl and contributors.  All rights reserved.
+# Copyright (c) 2013-2022, Georg Brandl and contributors.  All rights reserved.
 # Licensed under a 2-clause BSD license, see LICENSE.
 # *****************************************************************************
 
 """Panel for mappings."""
 
-from numpy import array, mgrid, savetxt
+from numpy import array, mgrid, savetxt, ptp
 from matplotlib.cbook import flatten
 
 from ufit.qt import QFrame, QMessageBox
 
 from ufit.data.dataset import Dataset
-from ufit.data.mapping import bin_mapping
+from ufit.data.mapping import bin_mapping, get_xss_yss_zss
 from ufit.models.peaks import Gauss2D
 from ufit.utils import attrdict
 from ufit.gui import logger
@@ -40,8 +40,8 @@ default_settings = {
     'yscale': 1,
     'zmin': -1e300,
     'zmax': 1e300,
-    'logz': False,
-    'gauss2d': True,
+    'logz': True,
+    'gauss2d': False,
 }
 
 
@@ -52,8 +52,21 @@ class MappingItem(SessionItem):
     def __init__(self, datas, settings):
         self.datas = datas
         self.settings = attrdict(settings or default_settings)
+        if settings is None:
+            for key in self.settings:
+                if 'map_' + key in session.props:
+                    self.settings[key] = getattr(session.props, 'map_' + key)
+            if self.settings.xaxis and self.settings.yaxis:
+                self._auto_select_yscale(self.settings.xaxis,
+                                         self.settings.yaxis)
         SessionItem.__init__(self)
 
+    def _auto_select_yscale(self, xaxis, yaxis):
+        xss, yss, _ = get_xss_yss_zss(xaxis, yaxis, self.datas)
+        xptp, yptp = ptp(xss), ptp(yss)
+        if yptp:
+            self.settings.yscale = float('%.2g' % (xptp / yptp))
+
     def __reduce__(self):
         return (self.__class__, (self.datas, self.settings))
 
@@ -62,10 +75,10 @@ class MappingItem(SessionItem):
 
     def update_htmldesc(self):
         self.title = self.settings.title
-        self.htmldesc = '<img src=":/map.png">&nbsp;&nbsp;<big><b>%d</b></big> ' \
-                        '- %s<br>%s' % (
-                            self.index, self.settings.title,
-                            ', '.join(d.name for d in self.datas))
+        self.htmldesc = (
+            '<img src=":/map.png">&nbsp;&nbsp;<big><b>%d</b></big> '
+            '- %s<br>%s' % (self.index, self.settings.title,
+                            ', '.join(d.name for d in self.datas)))
         session.itemUpdated.emit(self)
 
 
@@ -125,8 +138,10 @@ class MappingPanel(QFrame):
         xaxis = str(self.xaxisBox.currentText())
         yaxis = str(self.yaxisBox.currentText())
         if xaxis != s.xaxis or yaxis != s.yaxis:
-            # new axes selected => discard limits on replot
+            # new axes selected => discard limits on replot and rescale
             self.mapdata = None
+            self.item._auto_select_yscale(xaxis, yaxis)
+            self.scaleEdit.setText('%.2g' % s.yscale)
         if xaxis == yaxis:
             QMessageBox.warning(self, 'Error', 'Please select distinct X '
                                 'and Y axes.')
@@ -142,6 +157,8 @@ class MappingPanel(QFrame):
         s.contour = self.contourBox.isChecked()
         s.logz = self.logBox.isChecked()
         s.gauss2d = self.fitBox.isChecked()
+        for key in s:
+            setattr(session.props, 'map_' + key, s[key])
         session.set_dirty()
 
     def on_buttonBox_clicked(self, button):
