@@ -2,7 +2,7 @@
 # *****************************************************************************
 # ufit, a universal scattering fitting suite
 #
-# Copyright (c) 2013-2020, Georg Brandl and contributors.  All rights reserved.
+# Copyright (c) 2013-2022, Georg Brandl and contributors.  All rights reserved.
 # Licensed under a 2-clause BSD license, see LICENSE.
 # *****************************************************************************
 
@@ -26,7 +26,7 @@ from ufit.gui.session import session, SessionItem
 from ufit.gui.mappingitem import MappingItem
 from ufit.gui.common import loadUi
 from ufit.gui.dialogs import ParamSetDialog
-from ufit.pycompat import from_encoding
+from ufit.utils import from_encoding
 
 
 def default_model(data):
