@@ -2,19 +2,19 @@
 # *****************************************************************************
 # ufit, a universal scattering fitting suite
 #
-# Copyright (c) 2013-2020, Georg Brandl and contributors.  All rights reserved.
+# Copyright (c) 2013-2022, Georg Brandl and contributors.  All rights reserved.
 # Licensed under a 2-clause BSD license, see LICENSE.
 # *****************************************************************************
 
 """Session and session item abstraction."""
 
+import pickle
 from os import path
 
 from ufit.qt import QObject, pyqtSignal
 
 from ufit import UFitError
 from ufit.utils import attrdict
-from ufit.pycompat import six, cPickle as pickle
 
 
 # current save file version
@@ -61,7 +61,7 @@ class SessionItem(QObject):
         """Export fits as ASCII data."""
 
 
-class ItemGroup(object):
+class ItemGroup:
     expanded = False
 
     def __init__(self, name):
@@ -157,10 +157,7 @@ class UfitSession(QObject):
         self.clear()
         # unpickle everything
         with open(filename, 'rb') as fp:
-            if six.PY3:
-                info = pickle.load(fp, encoding='latin1')
-            else:
-                info = pickle.load(fp)
+            info = pickle.load(fp, encoding='latin1')
         # load with the respective method
         savever = info.get('version', 0)
         try:
