@@ -2,7 +2,7 @@
 # *****************************************************************************
 # ufit, a universal scattering fitting suite
 #
-# Copyright (c) 2013-2019, Georg Brandl and contributors.  All rights reserved.
+# Copyright (c) 2013-2022, Georg Brandl and contributors.  All rights reserved.
 # Licensed under a 2-clause BSD license, see LICENSE.
 # *****************************************************************************
 
@@ -14,7 +14,7 @@ from numpy import array, isscalar, linspace
 
 import matplotlib
 matplotlib.rc('font', **{'sans-serif': 'Sans Serif, Arial, Helvetica, '
-                     'Lucida Grande, Bitstream Vera Sans'})
+                         'Lucida Grande, Bitstream Vera Sans'})
 matplotlib.rc('savefig', format='pdf')
 
 from matplotlib import pyplot as pl
@@ -34,7 +34,7 @@ def multi_linspace(start, stop, steps):
                   for i in range(len(start))]).T
 
 
-class DataPlotter(object):
+class DataPlotter:
 
     markers = ['o', 's', 'v', '*', 'd', '^', '>', 'p']
 
