@@ -2,7 +2,7 @@
 # *****************************************************************************
 # ufit, a universal scattering fitting suite
 #
-# Copyright (c) 2013-2019, Georg Brandl and contributors.  All rights reserved.
+# Copyright (c) 2013-2021, Georg Brandl and contributors.  All rights reserved.
 # Licensed under a 2-clause BSD license, see LICENSE.
 # *****************************************************************************
 
@@ -22,7 +22,7 @@ from numpy.random import randn
 from numpy.linalg import inv, det, eig, norm
 
 
-class unitcell(object):
+class unitcell:
     """
     Class which models a crystallographic unit cell from given lattice
     parameters and angles.  Further it provides functions to make basic
@@ -333,7 +333,7 @@ MEV2AA2 = 0.48259642  # hbar**2/(2 * m_n)
 MIN2RAD = 1/60. * pi/180.
 
 
-class resmat(object):
+class resmat:
     """Class which calculates the resolution matrix, and the renormalisation
     volume R0 for a given triple axis parameter set which describes a specific
     setup at a specific instrument by using the Popovici method (REF).
@@ -1213,7 +1213,7 @@ def single_mc(NMC, sqw, fit_par, QE, b_mat, sigma, R0_corrected):
 pool = None
 
 
-class dummy_result(object):
+class dummy_result:
     def __init__(self, res):
         self.res = res
 
